import React, { useState, useEffect } from 'react'
import {
  TableContainer,
  Table,
  TableHead,
  TableRow,
  TableCell,
  TableBody,
  Paper,
  Typography,
  TablePagination,
  Skeleton,
  TextField,
  MenuItem,
  Select,
  FormControl,
  InputLabel,
  Grid,
  Button,
} from '@mui/material'
import axios from 'axios'
import Axios from '../../../axios'

function StockTable({ apiEndpoint, totalProducts }) {
  const [stocks, setStocks] = useState([])
  const [loading, setLoading] = useState(true)
  const [page, setPage] = useState(0)
  const [rowsPerPage, setRowsPerPage] = useState(5)
  const [category, setCategory] = useState('')
  const [brand, setBrand] = useState('')
  const [productName, setProductName] = useState('')
  const [isInitialStockMode, setIsInitialStockMode] = useState(false)
  const [initialStock, setInitialStock] = useState([])
  const [products, setProducts] = useState()

  console.log(initialStock, 'initial stock ')

  const fetchProducts = async () => {
    try {
      const response = await Axios.get('/api/product/getAll/user/')
      setProducts(response.data?.products || [])
      console.log(response, 'resp of products ')
    } catch (error) {
      console.log(error)
    }
    const response = await Axios.get('/api/product/getAll/user/')
    setProducts(response.data?.products || [])
  }
  // Fetch Products from Backend API
  const fetchStocks = async () => {
    setLoading(true)
    try {
      const response = await axios.get(apiEndpoint, {
        params: { category, brand, productName, page, limit: rowsPerPage },
      })
      setStocks(response.data.stocks)
    } catch (error) {
      console.error('Error fetching products:', error)
    } finally {
      setLoading(false)
    }
  }
  useEffect(() => {
    fetchProducts()
  }, [])
  useEffect(() => {
    fetchStocks()
  }, [category, brand, productName, page, rowsPerPage])

  // Pagination Handlers
  const handleChangePage = (event, newPage) => setPage(newPage)
  const handleChangeRowsPerPage = (event) => {
    setRowsPerPage(parseInt(event.target.value, 10))
    setPage(0)
  }

  const handleStockChange = (productId, value) => {
    setInitialStock((prevStock) => {
      const stockExists = prevStock.find((item) => item.productId === productId)

      if (stockExists) {
        // Update the existing stock entry
        return prevStock.map((item) =>
          item.productId === productId ? { ...item, stock: value } : item,
        )
      } else {
        // Add a new stock entry
        return [...prevStock, { productId, stock: value }]
      }
    })
  }

  const handleSubmitInitialStock = async () => {
    try {
      await axios.post(`${apiEndpoint}/initial-stock`, { stock: initialStock })
      setIsInitialStockMode(false)
      fetchProducts()
    } catch (error) {
      console.error('Error adding initial stock:', error)
    }
  }

  const formatDateTime = (dateString) => {
    const date = new Date(dateString)
    return `${date.toDateString()}, ${formatAMPM(date)}`
  }

  const formatAMPM = (date) => {
    let hours = date.getHours()
    const minutes = date.getMinutes()
    const ampm = hours >= 12 ? 'PM' : 'AM'
    hours = hours % 12 || 12
    return `${hours}:${minutes < 10 ? '0' + minutes : minutes} ${ampm}`
  }

  // Check if stock exists
  const stockExists = stocks.length > 0

  return (
    <div style={{ background: '#fff', padding: '1rem' }}>
      {!stockExists && !isInitialStockMode ? (
        <Button variant="contained" onClick={() => setIsInitialStockMode(true)}>
          Add Initial Stock
        </Button>
      ) : isInitialStockMode ? (
        <>
          <Typography variant="h6" gutterBottom>
            Add Initial Stock
          </Typography>
          <TableContainer component={Paper}>
            <Table>
              <TableHead>
                <TableRow>
                  <TableCell>Product Name</TableCell>
                  <TableCell>SKU</TableCell>
                  <TableCell>Stock</TableCell>
                </TableRow>
              </TableHead>
              <TableBody>
                {products.map((product) => (
                  <TableRow key={product._id}>
                    <TableCell>{product.name}</TableCell>
                    <TableCell>{product.SKU}</TableCell>
                    <TableCell>
                      <TextField
                        type="number"
                        value={
                          initialStock.find((item) => item.productId === product._id)?.stock || ''
                        }
                        onChange={(e) => handleStockChange(product._id, e.target.value)}
                      />
                    </TableCell>
                  </TableRow>
                ))}
              </TableBody>
            </Table>
          </TableContainer>
          <Button
            variant="contained"
            color="primary"
            onClick={handleSubmitInitialStock}
            sx={{ marginTop: 2 }}
          >
            Submit Stock
          </Button>
        </>
      ) : (
        <>
          {/* Filter Controls */}
          <Grid container spacing={2} sx={{ marginBottom: 2 }}>
            <Grid item xs={12} md={4}>
              <FormControl fullWidth>
                <InputLabel>Category</InputLabel>
                <Select
                  value={category}
                  onChange={(e) => setCategory(e.target.value)}
                  label="Category"
                >
                  <MenuItem value="">All</MenuItem>
                  <MenuItem value="Electronics">Electronics</MenuItem>
                  <MenuItem value="Clothing">Clothing</MenuItem>
                  <MenuItem value="Furniture">Furniture</MenuItem>
                </Select>
              </FormControl>
            </Grid>
            <Grid item xs={12} md={4}>
              <FormControl fullWidth>
                <InputLabel>Brand</InputLabel>
                <Select value={brand} onChange={(e) => setBrand(e.target.value)} label="Brand">
                  <MenuItem value="">All</MenuItem>
                  <MenuItem value="Apple">Apple</MenuItem>
                  <MenuItem value="Nike">Nike</MenuItem>
                  <MenuItem value="Ikea">Ikea</MenuItem>
                </Select>
              </FormControl>
            </Grid>
            <Grid item xs={12} md={4}>
              <TextField
                fullWidth
                label="Product Name"
                value={productName}
                onChange={(e) => setProductName(e.target.value)}
              />
            </Grid>
          </Grid>

          {/* Products Table */}
          <TableContainer component={Paper}>
            <Table>
              <TableHead>
                <TableRow>
                  <TableCell>Product Name</TableCell>
                  <TableCell>SKU</TableCell>
                  <TableCell>Category</TableCell>
                  <TableCell>Brand</TableCell>
                  <TableCell>Added On</TableCell>
                  <TableCell>Price</TableCell>
                  <TableCell>Stock</TableCell>
                </TableRow>
              </TableHead>
              <TableBody>
                {loading ? (
                  Array.from(new Array(rowsPerPage)).map((_, index) => (
                    <TableRow key={index}>
                      <TableCell colSpan={7}>
                        <Skeleton height={40} />
                      </TableCell>
                    </TableRow>
                  ))
                ) : stocks.length > 0 ? (
                  products.map((product) => (
                    <TableRow key={product._id}>
                      <TableCell>{product.name}</TableCell>
                      <TableCell>{product.sku}</TableCell>
                      <TableCell>{product.categoryName}</TableCell>
                      <TableCell>{product.brandName}</TableCell>
                      <TableCell>{formatDateTime(product.addedOn)}</TableCell>
                      <TableCell>{product.price.toFixed(2)}</TableCell>
                      <TableCell>{product.stock}</TableCell>
                    </TableRow>
                  ))
                ) : (
                  <TableRow>
                    <TableCell colSpan={7} align="center">
                      <Typography variant="body1">Data not found</Typography>
                    </TableCell>
                  </TableRow>
                )}
              </TableBody>
            </Table>
            <TablePagination
              rowsPerPageOptions={[5, 10, 25]}
              component="div"
              count={totalProducts}
              rowsPerPage={rowsPerPage}
              page={page}
              onPageChange={handleChangePage}
              onRowsPerPageChange={handleChangeRowsPerPage}
            />
          </TableContainer>
        </>
      )}
    </div>
  )
}

export default StockTable
